@echo off
rem ###############################################################################
rem # Licensed Materials - Property of IBM
rem # 5724-T40 IBM License Metric Tool
rem # 5724-S94 IBM Tivoli Asset Discovery for Distributed
rem #
rem # (C) Copyright IBM Corp. 2004, 2010.  All Rights Reserved.
rem #
rem # US Government Users Restricted Rights - Use, duplication or
rem # disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
rem ###############################################################################

set dir_path=%~1
set backup_dir=back

rem Checking the parameters:
if "%~1"=="" (
	echo Incorrect number of arguments
	echo usage: install.bat ILMT_or_TAD4D_install_dir
	pause
	exit 1
)
if not "%2"=="" (
	echo Incorrect number of arguments
	echo usage: install.bat ILMT_or_TAD4D_install_dir
	pause
	exit 1
)

echo Using ILMT/TAD4D install location: "%dir_path%"

rem Checking if provided dir exists
if not exist "%dir_path%" (
	echo "Error: %dir_path% file does not exist..."
	pause
	exit 1
)

rem Checking whether product.xml file exists in product installation directory
set product_xml_file="%dir_path%\product.xml"
if not exist %product_xml_file% (
	echo Error: There is no product.xml file in product installation directory
	echo Please check whether the given path is correct.
	pause
	exit 1
)

echo SUCCESS: product.xml file found in product installation directory...

call findstr "<Version>7.2.0.1</Version>" %product_xml_file%

if %ERRORLEVEL% NEQ 0 (
	echo Error: product version is NOT 7.2.0.1
	echo Current product version found: 
	call findstr "<Version>" %product_xml_file%
	echo Upgrade the server to 7.2.0.1 level and run the script again.
	pause
	exit 1
)

rem Checking whether it is ILMT or TAD4D installation
set lmt_war_path="%dir_path%\eWAS\systemApps\isclite.ear\lmt_admin.war"
set tad4d_war_path="%dir_path%\eWAS\systemApps\isclite.ear\tad4d_admin.war"
set admin_libdir="%dir_path%\eWAS\systemApps\isclite.ear\lmt_admin.war\WEB-INF\lib"
set msghandler_libdir="%dir_path%\eWAS\profiles\AppSrv01\installedApps\cell1\LMT-TAD4D_Agent_message_handler.ear\com.ibm.license.mgmt.msghandler.web.war\WEB-INF\lib"

if exist %lmt_war_path% (
	echo ILMT 7.2.0.1 installation was found.
	goto checking_libs
)
if exist %tad4d_war_path% (
	echo TAD4D 7.2.0.1 installation was found.
	set admin_libdir="%dir_path%\eWAS\systemApps\isclite.ear\tad4d_admin.war\WEB-INF\lib\"
) else (
	echo Error: Cannot locate the product war directory
	pause
	exit 1
)

:checking_libs
rem Checking whether lib directories exists
if not exist %admin_libdir% (
	echo Error: %admin_libdir% lib directory cannot be located.
	pause
	exit 1
)
if not exist %msghandler_libdir% (
	echo "Error: the msghandler or admin server lib directory cannot be located."
	pause
	exit 1
)

rem Checking if the Interim Fix was already installed
set fix_file="%dir_path%\if1.dat"
if exist %fix_file% (
	echo Error: Interim Fix 7.2.0.1 IF1 is already installed.
	pause
	exit 1
)
echo SUCCESS: 7.2.0.1 IF1 was not yet installed, continuing...

rem Stopping the server
set srvstop="%dir_path%\cli\srvstop.bat"
if not exist %srvstop% (
	echo "Error: Cannot find srvstop.bat script to stop the server."
	pause
	exit 1
)
echo "Stopping the server ..."

call %srvstop%

set rc_stop=%errorlevel%
echo Stopping the server returned rc=%rc_stop%
if "%rc_stop%"=="0" (
echo SUCCESS: server stopped successfully...
goto Succesfull_stop
)
if "%rc_stop%"=="-10" (
echo SUCCESS: server was already stopped...
goto Succesfull_stop
)
echo Error: Server could not be stopped. Stop the server manually and run the script again.
pause
exit 1
:Succesfull_stop

rem Backup
echo Creating backup files
RD %backup_dir% /S /Q
mkdir %backup_dir%
if %errorlevel% neq 0 (
	echo Error: Cannot create the backup directory.
	pause
	exit 1
)

move /y %admin_libdir%\com.ibm.license.mgmt.srvfrontend.jar %backup_dir%
move /y %admin_libdir%\com.ibm.license.mgmt.dao.jar %backup_dir%
move /y %admin_libdir%\com.ibm.license.mgmt.admin.aggregation.jar %backup_dir%
move /y %admin_libdir%\com.ibm.license.mgmt.core.jar %backup_dir%
move /y %msghandler_libdir%\com.ibm.license.mgmt.msghandler.web.jar %backup_dir%

echo Replacing the jar files
xcopy com.ibm.license.mgmt.srvfrontend.jar %admin_libdir% /y /v
xcopy com.ibm.license.mgmt.dao.jar %admin_libdir% /y /v
xcopy com.ibm.license.mgmt.admin.aggregation.jar %admin_libdir% /y /v
xcopy com.ibm.license.mgmt.core.jar %admin_libdir% /y /v

xcopy com.ibm.license.mgmt.srvfrontend.jar %msghandler_libdir% /y /v
xcopy com.ibm.license.mgmt.dao.jar %msghandler_libdir% /y /v
xcopy com.ibm.license.mgmt.core.jar %msghandler_libdir% /y /v
xcopy com.ibm.license.mgmt.msghandler.web.jar %msghandler_libdir% /y /v

echo All files replaced

echo Creating a 7.2.0.1 IF1 InterimFix file...
echo 7.2.0.1 IF1 > %fix_file%

echo Starting the server...
set srvstart="%dir_path%\cli\srvstart.bat"

call %srvstart%

set rc_start=%errorlevel%
echo Starting the server returned rc=%rc_start%
if "%rc_start%"=="0" (
echo SUCCESS: server started successfully...
goto Succesfull_start
)
echo Warning: Server could not be started. Try to start the application server manually to finish the installation
pause
exit 2
:Succesfull_start

echo SUCCESS: ILMT/TAD4D 7.2.0.1 IF1 Interim Fix installation ended successfully.
pause
exit 0

